There is only one caller which hands in save_trace as function pointer.

Signed-off-by: Thomas Gleixner <t...@linutronix.de>
---
 kernel/locking/lockdep.c |   16 ++++++++--------
 1 file changed, 8 insertions(+), 8 deletions(-)

--- a/kernel/locking/lockdep.c
+++ b/kernel/locking/lockdep.c
@@ -2158,8 +2158,7 @@ check_deadlock(struct task_struct *curr,
  */
 static int
 check_prev_add(struct task_struct *curr, struct held_lock *prev,
-              struct held_lock *next, int distance, struct stack_trace *trace,
-              int (*save)(struct stack_trace *trace))
+              struct held_lock *next, int distance, struct stack_trace *trace)
 {
        struct lock_list *uninitialized_var(target_entry);
        struct lock_list *entry;
@@ -2199,11 +2198,11 @@ check_prev_add(struct task_struct *curr,
        if (unlikely(!ret)) {
                if (!trace->entries) {
                        /*
                         * If @save fails here, the printing might trigger
                         * a WARN but because of the !nr_entries it should
                         * not do bad things.
                         */
-                       save(trace);
+                       save_trace(trace);
                }
                return print_circular_bug(&this, target_entry, next, prev);
        }
@@ -2253,7 +2252,7 @@ check_prev_add(struct task_struct *curr,
                return print_bfs_bug(ret);
 
 
-       if (!trace->entries && !save(trace))
+       if (!trace->entries && !save_trace(trace))
                return 0;
 
        /*
@@ -2318,7 +2317,8 @@ check_prevs_add(struct task_struct *curr
                 * added:
                 */
                if (hlock->read != 2 && hlock->check) {
-                       int ret = check_prev_add(curr, hlock, next, distance, 
&trace, save_trace);
+                       int ret = check_prev_add(curr, hlock, next, distance,
+                                                &trace);
                        if (!ret)
                                return 0;
 
@@ -2199,11 +2198,11 @@ check_prev_add(struct task_struct *curr,
                if (!trace->entries) {
                        /*
-                        * If @save fails here, the printing might trigger
-                        * a WARN but because of the !nr_entries it should
-                        * not do bad things.
+                        * If save_trace fails here, the printing might
+                        * trigger a WARN but because of the !nr_entries it
+                        * should not do bad things.
                         */


_______________________________________________
dri-devel mailing list
dri-devel@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/dri-devel

Reply via email to